"use strict";
//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
Object.defineProperty(exports, "__esModule", { value: true });
exports.getForm = void 0;
var util_1 = require("primeobjects-ui-web-form/build/cjs/fields/util");
var primeobjects_helper_util_1 = require("primeobjects-helper-util");
var lodash_1 = require("lodash");
var getForm = function (customProps) {
    var primaryColor = customProps.primaryColor;
    var getRows = function (record) {
        return [
            {
                fields: [
                    {
                        name: "name",
                        alwaysShowLabel: true,
                        label: "Name",
                        type: "single-line-input",
                        placeholder: "Type the name here"
                    }
                ]
            },
            {
                fields: [
                    {
                        name: "version",
                        alwaysShowLabel: true,
                        label: "Version",
                        type: "single-line-input",
                        placeholder: "Type the version here"
                    }
                ]
            },
            {
                fields: [
                    {
                        name: "color",
                        label: "Theme",
                        type: "picklist",
                        defaultValue: JSON.stringify(primaryColor),
                        options: (0, util_1.getThemeOptions)(),
                        value: (0, lodash_1.isObject)(record.color)
                            ? JSON.stringify(record.color)
                            : record.color,
                        useFieldValue: true,
                        allowClear: false,
                        onChange: function (record) {
                            if ((0, primeobjects_helper_util_1.isNonEmptyString)(record.color)) {
                                var color = JSON.parse(record.color);
                                record.color = color;
                                record.color_data.value = color;
                            }
                            return record;
                        },
                        search: false,
                        required: true
                    }
                ]
            },
            {
                fields: [
                    {
                        name: "description",
                        alwaysShowLabel: true,
                        label: "Description",
                        type: "multi-line-input",
                        placeholder: "Type the description here"
                    }
                ]
            },
            {
                fields: [
                    {
                        name: "contactSection",
                        line: "Contact Information",
                        type: "section"
                    }
                ]
            },
            {
                fields: [
                    {
                        groupName: "contact",
                        name: "name",
                        alwaysShowLabel: true,
                        label: "Contact name",
                        placeholder: "Type the name here",
                        type: "single-line-input"
                    },
                    {
                        groupName: "contact",
                        name: "mobile",
                        alwaysShowLabel: true,
                        label: "Contact mobile number",
                        placeholder: "Type the mobile number here",
                        type: "single-line-input"
                    }
                ]
            },
            {
                fields: [
                    {
                        groupName: "contact",
                        name: "email",
                        alwaysShowLabel: true,
                        label: "Contact email address",
                        placeholder: "Type the email address here",
                        type: "single-line-input"
                    }
                ]
            },
            {
                fields: [
                    {
                        name: "senderSection",
                        line: "Sender Information",
                        subLine: "The senders defined here will be used in the email service and SMS service.",
                        type: "section"
                    }
                ]
            },
            {
                fields: [
                    {
                        groupName: "sender",
                        name: "name",
                        alwaysShowLabel: true,
                        label: "Sender's name",
                        placeholder: "Type the name here",
                        type: "single-line-input"
                    },
                    {
                        groupName: "sender",
                        name: "mobile",
                        alwaysShowLabel: true,
                        label: "Sender's mobile number",
                        placeholder: "Type the mobile number here",
                        type: "single-line-input"
                    }
                ]
            },
            {
                fields: [
                    {
                        groupName: "sender",
                        name: "email",
                        alwaysShowLabel: true,
                        label: "Sender's email address",
                        placeholder: "Type the email address here",
                        type: "single-line-input"
                    },
                    {
                        groupName: "sender",
                        name: "service",
                        alwaysShowLabel: true,
                        label: "Sender's email service",
                        placeholder: "Select an email service",
                        type: "picklist",
                        options: [
                            { text: "SendGrid", value: "sg" },
                            { text: "AWS SES", value: "ses" }
                        ]
                    }
                ]
            }
        ];
    };
    return {
        id: "general",
        tooltip: "General information",
        iconSrc: "/icons/platform/form.svg",
        getRows: getRows
    };
};
exports.getForm = getForm;
//# sourceMappingURL=general.js.map