"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getColumnsForParameters = void 0;
var react_1 = __importDefault(require("react"));
var lodash_1 = require("lodash");
var primeobjects_helper_util_1 = require("primeobjects-helper-util");
var primeobjects_ui_web_basic_1 = require("primeobjects-ui-web-basic");
var picklist_1 = __importDefault(require("primeobjects-ui-web-form/build/cjs/fields/picklist"));
var tooltip_1 = __importDefault(require("primeobjects-ui-web-application/build/cjs/controls/antd/tooltip"));
var single_line_input_1 = __importDefault(require("primeobjects-ui-web-form/build/cjs/fields/input/single-line-input"));
var checkbox_1 = __importDefault(require("primeobjects-ui-web-form/build/cjs/fields/checkbox"));
var getColumnsForParameters = function (props) {
    var primaryColor = props.primaryColor, record = props.record, toChangeRecord = props.toChangeRecord, includeKeyType = props.includeKeyType;
    return [
        {
            dataIndex: "required",
            width: 50,
            title: (react_1.default.createElement(tooltip_1.default, { color: primaryColor["600"], title: "Required parameter" },
                react_1.default.createElement("div", { style: { padding: "5px 0 5px 8px" }, className: "bg-gray-50 underline cursor-pointer" }, "Req."))),
            render: function (required, parameter, index) {
                (0, primeobjects_helper_util_1.doNothing)(parameter);
                return (react_1.default.createElement(checkbox_1.default, { wrapperStyle: { marginLeft: 5 }, boxStyle: {
                        border: "solid 1px ".concat(primeobjects_helper_util_1.COLORS.GRAY["200"])
                    }, id: "required".concat(index), value: required, onChange: function (newValue) {
                        record.parameters[index].required = newValue;
                        toChangeRecord(record);
                    } }));
            }
        },
        {
            dataIndex: "label",
            title: (react_1.default.createElement("div", { style: { padding: "5px 0 5px 5px" }, className: "bg-gray-50" }, "Label")),
            render: function (label, parameter, index) {
                (0, primeobjects_helper_util_1.doNothing)(parameter);
                return (react_1.default.createElement(single_line_input_1.default, { wrapperClassName: "w-full", inputWrapperStyle: {
                        border: "none"
                    }, inputClassName: "w-full input", inputStyle: {
                        border: "solid 1px ".concat(primeobjects_helper_util_1.COLORS.GRAY["200"]),
                        fontSize: "0.9rem"
                    }, format: "text", id: "label".concat(index), value: label, onChange: function (newValue) {
                        var newLabel = newValue !== null && newValue !== void 0 ? newValue : "";
                        var oriLabel = "".concat(record.parameters[index].label);
                        record.parameters[index].label = newLabel;
                        if (record.parameters[index].name == (0, primeobjects_helper_util_1.slug)(oriLabel)) {
                            record.parameters[index].name = (0, primeobjects_helper_util_1.slug)(newLabel);
                        }
                        toChangeRecord(record);
                    } }));
            }
        },
        {
            dataIndex: "name",
            title: (react_1.default.createElement("div", { style: { padding: "5px 0 5px 5px" }, className: "bg-gray-50" }, "Name")),
            render: function (name, parameter, index) {
                (0, primeobjects_helper_util_1.doNothing)(parameter);
                return (react_1.default.createElement(single_line_input_1.default, { inputWrapperStyle: {
                        border: "none"
                    }, inputClassName: "input", inputStyle: {
                        width: 120,
                        fontSize: "0.9rem",
                        border: "solid 1px ".concat(primeobjects_helper_util_1.COLORS.GRAY["200"])
                    }, format: "text", id: "name".concat(index), value: name, onChange: function (newValue) {
                        record.parameters[index].name = newValue;
                        toChangeRecord(record);
                    } }));
            }
        },
        {
            dataIndex: "type",
            width: 100,
            title: (react_1.default.createElement("div", { style: { padding: "5px 0 5px 5px" }, className: "bg-gray-50" }, "Type")),
            className: "padding-0-cell",
            render: function (type, parameter, index) {
                (0, primeobjects_helper_util_1.doNothing)(parameter);
                return (react_1.default.createElement(picklist_1.default, { id: "paramType", wrapperClassName: "border text-sm", controlStyle: {
                        fontSize: "0.9rem"
                    }, inputStyle: {
                        fontSize: "0.9rem",
                        border: "none",
                        paddingRight: 5,
                        marginRight: 5,
                        marginLeft: 5
                    }, defaultValue: "text", value: type, options: (0, lodash_1.filter)([
                        includeKeyType
                            ? { text: "Key/Token", value: "key" }
                            : {},
                        { text: "Content", value: "content" },
                        { text: "Text", value: "text" },
                        {
                            text: "Float",
                            value: "float"
                        },
                        {
                            text: "Integer",
                            value: "integer"
                        },
                        { text: "List", value: "list" }
                    ], function (r) {
                        return !(0, lodash_1.isEmpty)(r);
                    }), onChange: function (newValue) {
                        record.parameters[index].type = newValue;
                        toChangeRecord(record);
                    } }));
            }
        },
        {
            dataIndex: "remove",
            width: 20,
            title: (react_1.default.createElement("div", { style: { padding: "5px 0 5px 5px" }, className: "bg-gray-50" })),
            className: "padding-0-cell",
            render: function (type, parameter, index) {
                (0, primeobjects_helper_util_1.doNothing)({ type: type, parameter: parameter });
                return (react_1.default.createElement("div", { className: "w-full cursor-pointer", onClick: function () {
                        (0, lodash_1.pullAt)(record.parameters, [index]);
                        toChangeRecord(record);
                    } },
                    react_1.default.createElement(primeobjects_ui_web_basic_1.SVG, { src: "/icons/platform/circle-cancel-filled.svg", color: primeobjects_helper_util_1.COLORS.RED["400"], size: 18 })));
            }
        }
    ];
};
exports.getColumnsForParameters = getColumnsForParameters;
//# sourceMappingURL=api-parameters.js.map