//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import React from "react";
import { map, uniq, isArray } from "lodash";
import Button from "primeobjects-ui-web-application/build/cjs/controls/action-button";
import { COLORS, getRecordContent } from "primeobjects-helper-util";
import { callApi, getApiEndpoint } from "primeobjects-ui-web-application";
import { sendEvent } from "primeobjects-ui-web-basic/build/cjs/hooks/use-event";
import Lottie from "primeobjects-ui-web-basic/build/cjs/controls/lottie";
import { getLocalStorage, setLocalStorage } from "primeobjects-ui-web-basic";
export var SHORTEN_TAG_LOCAL_STORAGE_KEY = "shorten-tag";
export var MAX_TAG_LENGTH_TO_DISPLAY_LOCAL_STORAGE_KEY = "max-tag-length-to-display";
export var getForm = function (props) {
    var solution = props.solution, entity = props.entity, isError = props.isError, isDoing = props.isDoing, onStartAPICall = props.onStartAPICall, onFinishAPICall = props.onFinishAPICall, toChangeRecord = props.toChangeRecord, onErrorAPICall = props.onErrorAPICall, toRefreshForm = props.toRefreshForm, hideFullTagSettings = props.hideFullTagSettings, hideLocalTagsPoolButton = props.hideLocalTagsPoolButton, hideAWSButton = props.hideAWSButton, hideOpenAIButton = props.hideOpenAIButton, hideGoogleButton = props.hideGoogleButton, hideAIButtons = props.hideAIButtons, primaryColor = props.primaryColor, hideCategory = props.hideCategory;
    var maxTagLengthToDisplay = getLocalStorage(MAX_TAG_LENGTH_TO_DISPLAY_LOCAL_STORAGE_KEY, 12);
    var getRows = function (record) {
        var recordContent = getRecordContent(record);
        var shortenTag = getLocalStorage(SHORTEN_TAG_LOCAL_STORAGE_KEY, false);
        var onClickAITagsButton = function (service) {
            onStartAPICall("tags");
            callApi(solution, getApiEndpoint(solution, "content", "create-tags"), 
            // "http://localhost:3000/prod/create-tags",
            {
                content: recordContent,
                service: service,
                minScore: 7
            }, "POST")
                .then(function (result) {
                sendEvent("ai-credit-update-channel", Date.now());
                toChangeRecord(__assign(__assign({}, record), { tags: uniq(__spreadArray(__spreadArray([], (isArray(record.tags) ? record.tags : []), true), map(result.tags, function (t) { return t.text; }), true)) }));
            })
                .catch(function (error) {
                onErrorAPICall("tags", error);
                console.error(error);
            })
                .finally(function () {
                onFinishAPICall("tags");
            });
        };
        return [
            !hideCategory && {
                fields: [
                    {
                        alwaysShowLabel: true,
                        name: "categoryIds",
                        label: "Categories",
                        placeholder: "Select categories of the ".concat(entity.uiName),
                        entityName: "Category",
                        regardingEntityName: entity.entityName,
                        regardingEntityType: entity.entityType,
                        type: "multi-select-tree"
                    }
                ]
            },
            {
                fields: [
                    {
                        name: "tags",
                        label: "Tags",
                        type: "tags",
                        placeholder: "Type the tag of the ".concat(entity.uiName, " here"),
                        maxTagLengthToDisplay: !shortenTag
                            ? 0
                            : maxTagLengthToDisplay,
                        alwaysShowLabel: true
                    }
                ]
            },
            !hideFullTagSettings && {
                fields: [
                    {
                        colStyle: { maxWidth: !shortenTag ? "100%" : 200 },
                        wrapperClassName: "flex justify-center",
                        name: "shortenTag",
                        type: "checkbox",
                        label: "Shorten the long tags to improve reading experience",
                        inputSize: "small",
                        useFieldValue: true,
                        value: shortenTag,
                        size: "small",
                        skipRecordUpdate: true,
                        onChange: function (newRecord) {
                            setLocalStorage(SHORTEN_TAG_LOCAL_STORAGE_KEY, newRecord.shortenTag);
                            toRefreshForm();
                        }
                    },
                    shortenTag
                        ? {
                            colStyle: { maxWidth: 160 },
                            name: "maxTagLengthToDisplay",
                            type: "picklist",
                            hideLabel: true,
                            useFieldValue: true,
                            skipRecordUpdate: true,
                            value: maxTagLengthToDisplay,
                            options: [
                                {
                                    value: 12,
                                    text: "Max. 12 chars"
                                },
                                {
                                    value: 18,
                                    text: "Max. 18 chars"
                                },
                                {
                                    value: 22,
                                    text: "Max. 22 chars"
                                },
                                {
                                    value: 26,
                                    text: "Max. 26 chars"
                                },
                                {
                                    value: 30,
                                    text: "Max. 30 chars"
                                }
                            ],
                            onChange: function (newRecord) {
                                setLocalStorage(MAX_TAG_LENGTH_TO_DISPLAY_LOCAL_STORAGE_KEY, newRecord.maxTagLengthToDisplay);
                                toRefreshForm();
                            }
                        }
                        : { type: "placeholder", colStyle: { maxWidth: 0 } }
                ]
            },
            !hideAIButtons && {
                style: { paddingBottom: "0.5rem" },
                fields: [
                    {
                        name: "buttonsLabel",
                        lineStyle: { color: primaryColor["500"] },
                        lineClassName: "font-semibold",
                        line: "Use one of the AI services below to generate tags",
                        type: "label"
                    }
                ]
            },
            isDoing("tags") && {
                style: { paddingBottom: 0 },
                fields: [
                    {
                        name: "playgroundResultStream",
                        type: "container",
                        content: (React.createElement("div", { className: "flex flex-row w-full items-center" },
                            React.createElement("div", { className: "h-6" },
                                React.createElement(Lottie, { className: "w-full h-full", url: "/icons/platform/lottie/dots-2.json", colors: Array(6).fill(COLORS.GRAY[700]) })),
                            React.createElement("div", { className: "flex-1 text-sm text-gray-700 p-2" }, "Processing the content ...")))
                    }
                ]
            },
            !isDoing("tags") &&
                isError("tags") && {
                fields: [
                    {
                        name: "tagsFailed",
                        type: "alert-error",
                        line: "Sorry, we failed to generate the tags. Please try again later."
                    }
                ]
            },
            !isDoing("tags") &&
                !hideAIButtons &&
                recordContent.length > 0 && {
                section: "tagsAI",
                fields: [
                    {
                        name: "tagsAI",
                        colStyle: {
                            flex: 1,
                            alignItems: "flex-end"
                        },
                        content: (React.createElement("div", { className: "w-full" },
                            !hideGoogleButton && (React.createElement(Button, { id: "ai-tags-google-button", onClick: function () {
                                    onClickAITagsButton("google");
                                }, wrapperClassName: "bg-sky-500 hover:bg-sky-600 float-left mt-2 min-w-36 px-3 mr-2", wrapperStyle: { marginLeft: 0 }, text: "Google AI", textColor: COLORS.WHITE })),
                            !hideAWSButton && (React.createElement(Button, { id: "ai-tags-aws-button", onClick: function () {
                                    onClickAITagsButton("aws");
                                }, wrapperClassName: "bg-sky-500 hover:bg-sky-600 float-left mt-2 min-w-36 px-3 mr-2", wrapperStyle: { marginLeft: 0 }, text: "Amazon AI (AWS)", textColor: COLORS.WHITE })),
                            !hideOpenAIButton && (React.createElement(Button, { id: "ai-tags-open-ai-button", onClick: function () {
                                    onClickAITagsButton("open-ai");
                                }, wrapperClassName: "bg-sky-500 hover:bg-sky-600 float-left mt-2 min-w-36 px-3 mr-2", wrapperStyle: { marginLeft: 0 }, text: "Open AI (GPT-3)", textColor: COLORS.WHITE })),
                            !hideLocalTagsPoolButton && (React.createElement(Button, { id: "ai-tags-local-tags-pool-button", onClick: function () {
                                    onClickAITagsButton("local-pool");
                                }, wrapperClassName: "bg-sky-500 hover:bg-sky-600 float-left mt-2 min-w-36 px-3 mr-2", wrapperStyle: { marginLeft: 0 }, text: "Local tags pool", textColor: COLORS.WHITE })))),
                        type: "custom"
                    }
                ]
            }
        ];
    };
    return {
        id: "categories-tags",
        tooltip: "Categories & tags",
        getRows: getRows,
        iconSrc: "/icons/platform/tags.svg",
        alwaysShowLabel: true
    };
};
//# sourceMappingURL=categories-tags-form.js.map