import React from "react";
import { pullAt, isEmpty, filter } from "lodash";
import { COLORS, doNothing, slug } from "primeobjects-helper-util";
import { SVG } from "primeobjects-ui-web-basic";
import PicklistField from "primeobjects-ui-web-form/build/cjs/fields/picklist";
import Tooltip from "primeobjects-ui-web-application/build/cjs/controls/antd/tooltip";
import SingleLineInputField from "primeobjects-ui-web-form/build/cjs/fields/input/single-line-input";
import CheckboxField from "primeobjects-ui-web-form/build/cjs/fields/checkbox";
export var getColumnsForParameters = function (props) {
    var primaryColor = props.primaryColor, record = props.record, toChangeRecord = props.toChangeRecord, includeKeyType = props.includeKeyType;
    return [
        {
            dataIndex: "required",
            width: 50,
            title: (React.createElement(Tooltip, { color: primaryColor["600"], title: "Required parameter" },
                React.createElement("div", { style: { padding: "5px 0 5px 8px" }, className: "bg-gray-50 underline cursor-pointer" }, "Req."))),
            render: function (required, parameter, index) {
                doNothing(parameter);
                return (React.createElement(CheckboxField, { wrapperStyle: { marginLeft: 5 }, boxStyle: {
                        border: "solid 1px ".concat(COLORS.GRAY["200"])
                    }, id: "required".concat(index), value: required, onChange: function (newValue) {
                        record.parameters[index].required = newValue;
                        toChangeRecord(record);
                    } }));
            }
        },
        {
            dataIndex: "label",
            title: (React.createElement("div", { style: { padding: "5px 0 5px 5px" }, className: "bg-gray-50" }, "Label")),
            render: function (label, parameter, index) {
                doNothing(parameter);
                return (React.createElement(SingleLineInputField, { wrapperClassName: "w-full", inputWrapperStyle: {
                        border: "none"
                    }, inputClassName: "w-full input", inputStyle: {
                        border: "solid 1px ".concat(COLORS.GRAY["200"]),
                        fontSize: "0.9rem"
                    }, format: "text", id: "label".concat(index), value: label, onChange: function (newValue) {
                        var newLabel = newValue !== null && newValue !== void 0 ? newValue : "";
                        var oriLabel = "".concat(record.parameters[index].label);
                        record.parameters[index].label = newLabel;
                        if (record.parameters[index].name == slug(oriLabel)) {
                            record.parameters[index].name = slug(newLabel);
                        }
                        toChangeRecord(record);
                    } }));
            }
        },
        {
            dataIndex: "name",
            title: (React.createElement("div", { style: { padding: "5px 0 5px 5px" }, className: "bg-gray-50" }, "Name")),
            render: function (name, parameter, index) {
                doNothing(parameter);
                return (React.createElement(SingleLineInputField, { inputWrapperStyle: {
                        border: "none"
                    }, inputClassName: "input", inputStyle: {
                        width: 120,
                        fontSize: "0.9rem",
                        border: "solid 1px ".concat(COLORS.GRAY["200"])
                    }, format: "text", id: "name".concat(index), value: name, onChange: function (newValue) {
                        record.parameters[index].name = newValue;
                        toChangeRecord(record);
                    } }));
            }
        },
        {
            dataIndex: "type",
            width: 100,
            title: (React.createElement("div", { style: { padding: "5px 0 5px 5px" }, className: "bg-gray-50" }, "Type")),
            className: "padding-0-cell",
            render: function (type, parameter, index) {
                doNothing(parameter);
                return (React.createElement(PicklistField, { id: "paramType", wrapperClassName: "border text-sm", controlStyle: {
                        fontSize: "0.9rem"
                    }, inputStyle: {
                        fontSize: "0.9rem",
                        border: "none",
                        paddingRight: 5,
                        marginRight: 5,
                        marginLeft: 5
                    }, defaultValue: "text", value: type, options: filter([
                        includeKeyType
                            ? { text: "Key/Token", value: "key" }
                            : {},
                        { text: "Content", value: "content" },
                        { text: "Text", value: "text" },
                        {
                            text: "Float",
                            value: "float"
                        },
                        {
                            text: "Integer",
                            value: "integer"
                        },
                        { text: "List", value: "list" }
                    ], function (r) {
                        return !isEmpty(r);
                    }), onChange: function (newValue) {
                        record.parameters[index].type = newValue;
                        toChangeRecord(record);
                    } }));
            }
        },
        {
            dataIndex: "remove",
            width: 20,
            title: (React.createElement("div", { style: { padding: "5px 0 5px 5px" }, className: "bg-gray-50" })),
            className: "padding-0-cell",
            render: function (type, parameter, index) {
                doNothing({ type: type, parameter: parameter });
                return (React.createElement("div", { className: "w-full cursor-pointer", onClick: function () {
                        pullAt(record.parameters, [index]);
                        toChangeRecord(record);
                    } },
                    React.createElement(SVG, { src: "/icons/platform/circle-cancel-filled.svg", color: COLORS.RED["400"], size: 18 })));
            }
        }
    ];
};
//# sourceMappingURL=api-parameters.js.map